@@ -1,7 +1,6 @@
 package Smart::Comments;
-
-our $VERSION = '1.000004';
-
+$Smart::Comments::VERSION = '1.06';
+use 5.008;
 use warnings;
 use strict;
 use Carp;
@@ -493,7 +492,7 @@ Smart::Comments - Comments that do more than just sit there
 
 =head1 VERSION
 
-This document describes Smart::Comments version 1.000004
+This document describes Smart::Comments version 1.000005
 
 
 =head1 SYNOPSIS
@@ -522,7 +521,7 @@ This document describes Smart::Comments version 1.000004
         do_something_expensive_with($i);
     }
 
-  
+
 =head1 DESCRIPTION
 
 Smart comments provide an easy way to insert debugging and tracking code
@@ -726,7 +725,7 @@ For example, given the following assertion:
 
 if the expression evaluated false, the comment would die with the following
 message:
- 
+
     ### $min < $result && $result < $max was not true at demo.pl line 86.
     ###     $min was: 7
     ###     $result was: 1000004
@@ -849,7 +848,7 @@ example:
 
     for (@candidates) {       ### Evaluating |===[%]    |
 
-would be aninated like so:
+would be animated like so:
 
     Evaluating |[0%]                       |
 
@@ -1021,23 +1020,23 @@ The module requires the following modules:
 
 =item *
 
-Filter::Simple
+L<Filter::Simple>
 
 =item *
 
-version.pm
+L<version>
 
 =item *
 
-List::Util
+L<List::Util>
 
 =item *
 
-Data::Dumper
+L<Data::Dumper>
 
 =item *
 
-Text::Balanced
+L<Text::Balanced>
 
 =back
 
@@ -1060,6 +1059,11 @@ C<bug-smart-comments@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/Smart-Comments>
+
+
 =head1 AUTHOR
 
 Damian Conway  C<< <DCONWAY@cpan.org> >>
